%define py2_incdir %{_includedir}/python%{python_version}
%define py3_incdir %{_includedir}/python%{python3_version}
%define py2_libbuilddir %(python -c 'import sys; import sysconfig; print("lib.{p}-{v[0]}.{v[1]}".format(p=sysconfig.get_platform(), v=sys.version_info))')
%define py3_libbuilddir %(python3 -c 'import sys; import sysconfig; print("lib.{p}-{v[0]}.{v[1]}".format(p=sysconfig.get_platform(), v=sys.version_info))')

%define name3 python3-pillow

# Refer to the comment for Source0 below on how to obtain the source tarball
# The saved file has format python-imaging-Pillow-$version-$ahead-g$shortcommit.tar.gz
%define commit 3c2496e117f4d045a99d7e376133e67b47217ce2 
%define shortcommit %(c=%{commit}; echo ${c:0:7}) 
%define ahead 0

# If ahead is 0, the tarball corresponds to a release version, otherwise to a git snapshot
%if %{ahead} > 0
%define snap .git%{shortcommit}
%endif

Name:           python-pillow
Version:        2.2.1
Release:        %mkrel 0%{?snap}.4
Summary:        Python image processing library

Group:          Development/Python
License:        MIT
URL:            http://python-imaging.github.io/

# Obtain the tarball for a certain commit via:
#  wget --content-disposition https://github.com/python-imaging/Pillow/tarball/$commit
Source0:        https://github.com/python-imaging/Pillow/tarball/%{commit}/python-imaging-Pillow-%{version}-%{ahead}-g%{shortcommit}.tar.gz
Patch0:		python-pillow-CVE-2014-1932-CVE-2014-1933.patch

BuildRequires:  pkgconfig(python)
BuildRequires:  python-setuptools
BuildRequires:  tkinter
BuildRequires:  tk-devel
BuildRequires:  python-sphinx
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(lcms)
BuildRequires:  pkgconfig(sane-backends)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  PyQt4
BuildRequires:  python-numpy
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(python-3.3)
BuildRequires:  python3-setuptools
BuildRequires:  tkinter3
BuildRequires:  python3-PyQt4
BuildRequires:  python3-numpy

Provides:       python-imaging = %{version}-%{release}
Obsoletes:      python-imaging <= 1.1.7-12

%description
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are five subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
sane (scanning devices interface), devel (development) and doc (documentation).


%package devel
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python-devel, libjpeg-devel, zlib-devel
Provides:       python-imaging-devel = %{version}-%{release}
Obsoletes:      python-imaging-devel <= 1.1.7-12

%description devel
Development files for %{name}.


%package doc
Summary:        Documentation for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Documentation for %{name}.


%package sane
Summary:        Python module for using scanners
Group:          System/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       python-imaging-sane = %{version}-%{release}
Obsoletes:      python-imaging-sane <= 1.1.7-12

%description sane
This package contains the sane module for Python which provides access to
various raster scanning devices such as flatbed scanners and digital cameras.


%package tk
Summary:        Tk interface for %{name}
Group:          System/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       tkinter
Provides:       python-imaging-tk = %{version}-%{release}
Obsoletes:      python-imaging-tk <= 1.1.7-12

%description tk
Tk interface for %{name}.

%package qt
Summary:        PIL image wrapper for Qt
Group:          System/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       PyQt4
Provides:       python-imaging-qt = %{version}-%{release}

%description qt
PIL image wrapper for Qt.


%package -n %{name3}
Group:          Development/Python
Summary:        Python 3 image processing library
Provides:       python3-imaging = %{version}-%{release}
Provides:       %{name3} = %{version}-%{release}

%description -n %{name3}
%{_description}


%package -n %{name3}-devel
Summary:        Development files for %{name3}
Group:          Development/C
Requires:       %{name3}%{?_isa} = %{version}-%{release}
Requires:       python3-devel, libjpeg-devel, zlib-devel

%description -n %{name3}-devel
Development files for %{name3}.


%package -n %{name3}-doc
Summary:        Documentation for %{name3}
Group:          Documentation
Requires:       %{name3} = %{version}-%{release}
BuildArch:      noarch

%description -n %{name3}-doc
Documentation for %{name3}.


%package -n %{name3}-sane
Summary:        Python module for using scanners
Group:          System/Libraries
Requires:       %{name3}%{?_isa} = %{version}-%{release}

%description -n %{name3}-sane
This package contains the sane module for Python which provides access to
various raster scanning devices such as flatbed scanners and digital cameras.


%package -n %{name3}-tk
Summary:        Tk interface for %{name3}
Group:          System/Libraries
Requires:       %{name3}%{?_isa} = %{version}-%{release}
Requires:       tkinter

%description -n %{name3}-tk
Tk interface for %{name3}.

%package -n %{name3}-qt
Summary:        PIL image wrapper for Qt
Group:          System/Libraries
Requires:       %{name3}%{?_isa} = %{version}-%{release}
Requires:       python3-PyQt4

%description -n %{name3}-qt
PIL image wrapper for Qt.

%prep
%setup -q -n python-imaging-Pillow-%{shortcommit}
%patch0 -p1


# Create Python 3 source tree
cp -a . %{py3dir}

%build
# Build Python 2 modules
find -name '*.py' | xargs sed -i '1s|^#!.*python|#!%{__python}|'
CFLAGS="%{optflags}" %{__python} setup.py build

pushd Sane
CFLAGS="%{optflags}" %{__python} setup.py build
popd

pushd docs
PYTHONPATH=$PWD/.. make html
rm -f _build/html/.buildinfo
popd

# Build Python 3 modules
pushd %{py3dir}
find -name '*.py' | xargs sed -i '1s|^#!.*python|#!%{__python3}|'
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build

pushd Sane
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build
popd

pushd docs
PYTHONPATH=$PWD/.. make html
rm -f _build/html/.buildinfo
popd
popd

%install
# Install Python 2 modules
install -d $RPM_BUILD_ROOT/%{py2_incdir}/Imaging
install -m 644 libImaging/*.h $RPM_BUILD_ROOT/%{py2_incdir}/Imaging
%{__python} setup.py install --skip-build --root $RPM_BUILD_ROOT
pushd Sane
%{__python} setup.py install --skip-build --root $RPM_BUILD_ROOT
popd

# Install Python 3 modules
pushd %{py3dir}
install -d $RPM_BUILD_ROOT/%{py3_incdir}/Imaging
install -m 644 libImaging/*.h $RPM_BUILD_ROOT/%{py3_incdir}/Imaging
%{__python3} setup.py install --skip-build --root $RPM_BUILD_ROOT
pushd Sane
%{__python3} setup.py install --skip-build --root $RPM_BUILD_ROOT
popd
popd

# The scripts are packaged in %%doc
rm -rf $RPM_BUILD_ROOT%{_bindir}

%check
# Check Python 2 modules
ln -s $PWD/Images $PWD/build/%py2_libbuilddir/Images
cp -R $PWD/Tests $PWD/build/%py2_libbuilddir/Tests
cp -R $PWD/selftest.py $PWD/build/%py2_libbuilddir/selftest.py
pushd build/%py2_libbuilddir
PYTHONPATH=$PWD/build/%py2_libbuilddir %{__python} selftest.py
PYTHONPATH=$PWD/build/%py2_libbuilddir %{__python} Tests/run.py
popd

# Check Python 3 modules
pushd %{py3dir}
ln -s $PWD/Images $PWD/build/%py3_libbuilddir/Images
cp -R $PWD/Tests $PWD/build/%py3_libbuilddir/Tests
cp -R $PWD/selftest.py $PWD/build/%py3_libbuilddir/selftest.py
pushd build/%py3_libbuilddir
PYTHONPATH=$PWD/build/%py3_libbuilddir %{__python3} selftest.py
PYTHONPATH=$PWD/build/%py3_libbuilddir %{__python3} Tests/run.py
popd

%files
%doc README.rst CHANGES.rst docs/COPYING
%{python_sitearch}/*
# These are in subpackages
%exclude %{python_sitearch}/*sane*
%exclude %{python_sitearch}/PIL/_imagingtk*
%exclude %{python_sitearch}/PIL/ImageTk*
%exclude %{python_sitearch}/PIL/SpiderImagePlugin*
%exclude %{python_sitearch}/PIL/ImageQt*

%files devel
%{py2_incdir}/Imaging/

%files doc
%doc Scripts Images docs/_build/html

%files sane
%doc Sane/CHANGES Sane/demo*.py Sane/sanedoc.txt
%{python_sitearch}/*sane*

%files tk
%{python_sitearch}/PIL/_imagingtk*
%{python_sitearch}/PIL/ImageTk*
%{python_sitearch}/PIL/SpiderImagePlugin*

%files qt
%{python_sitearch}/PIL/ImageQt*

%files -n %{name3}
%doc README.rst CHANGES.rst docs/COPYING
%{python3_sitearch}/*
# These are in subpackages
%exclude %{python3_sitearch}/*sane*
%exclude %{python3_sitearch}/PIL/_imagingtk*
%exclude %{python3_sitearch}/PIL/ImageTk*
%exclude %{python3_sitearch}/PIL/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/ImageQt*

%files -n %{name3}-devel
%{py3_incdir}/Imaging/

%files -n %{name3}-doc
%doc Scripts Images docs/_build/html

%files -n %{name3}-sane
%doc Sane/CHANGES Sane/demo*.py Sane/sanedoc.txt
%{python3_sitearch}/*sane*

%files -n %{name3}-tk
%{python3_sitearch}/PIL/_imagingtk*
%{python3_sitearch}/PIL/ImageTk*
%{python3_sitearch}/PIL/SpiderImagePlugin*

%files -n %{name3}-qt
%{python3_sitearch}/PIL/ImageQt*



%changelog
* Sun Mar 23 2014 luigiwalser <luigiwalser> 2.2.1-0.4.mga4
+ Revision: 606968
- rediff patch from debian to fix CVE-2014-1932 and CVE-2014-1933

* Tue Oct 22 2013 umeabot <umeabot> 2.2.1-0.3.mga4
+ Revision: 544030
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.2.1-0.2.mga4
+ Revision: 499118
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Oct 04 2013 philippem <philippem> 2.2.1-0.1.mga4
+ Revision: 491495
- Update to 2.2.1

* Sat Sep 07 2013 philippem <philippem> 2.1.0-0.2.mga4
+ Revision: 475735
- Add patch to fix memory corruption caused by invalid palette size, mga#10729

* Mon Jul 08 2013 philippem <philippem> 2.1.0-0.1.mga4
+ Revision: 451502
- Update to 2.1.0
- Update to 2.1.0

* Wed Jul 03 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.4.mga4
+ Revision: 449875
- obsolete old PIL

* Mon Jul 01 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.3.mga4
+ Revision: 448886
+ rebuild (emptylog)

* Sat Jun 29 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.2.mga4
+ Revision: 448390
- add provides

* Sat Jun 29 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.1.mga4
+ Revision: 448268
- fix groups
- add Python3
- add missing BR
- imported package python-pillow

